
| Attribute Name  | Input Required? | Generated/Default? | Unique? | Notes | Type                     
|:----------------| :- | :- | :- | :-|:-------------------------|
| Term Name       | Yes | No | No | A display name (informal name). | string                   |
| Owning Glossary | Yes | No | Yes | This is the qualified name of the glossary that owns this term. | Qualified name reference |
| Categories      | No | No | Yes | This is the qualified (unique) name of the category. Multiple categories can be assigned, separated by a `,` or line. | qualified name reference
| Description     | No | No  | No | A textual description of this term | string |
| Qualified Name  | No | Yes | Yes | The qualified name can either be provided by the user or generated. If generated, a pattern is followed. | mfg or supplied q_name |
| GUID            | No | Yes | Yes | GUIDs are always generated by Egeria. They are meant for automation, not people. | Generated
